@@ -27,7 +27,7 @@ class Population:
         for i in range(size):
             self.birds.append(Bird(hl_count, layer_node_counts)) 
 
-    def breed(self):
+    def breed(self, immune=1):
         odds = []
         total_fit = 0
         for i in self.birds:
@@ -36,7 +36,7 @@ class Population:
             odds.append(i.fitness / (total_fit - i.fitness))
         odds /= np.sum(odds)
         
-        next_gen = []
+        next_gen = sorted(self.birds, key=lambda x: x.fitness, reverse=True)[:immune]
         while len(next_gen) < len(self.birds):
             p1 = np.random.choice(self.birds, 1, p=odds)[0]
             p2 = np.random.choice(self.birds, 1, p=odds)[0]
@@ -47,6 +47,7 @@ class Population:
                         if np.random.uniform() < .5:
                             mats[matrix][row][col] = p2.matrices[matrix][row][col]
             next_gen.append(Bird(0, 0, mat=mats))
+        next_gen = copy.deepcopy(next_gen)
         for i in range(len(self.birds)):
             del self.birds[-1]
         self.birds = next_gen
